Description Usage Arguments Value
Builds all the derived variables used in the partitioning such as CSWI, DWCI, etc., as well as filters which remove night time, low air temp/GPP, etc. periods.
1 | tea_preprocess(data, control = tea_config())
|
data |
data.frame of full days, must contain at least timestamp, ET, GPP, RH, Rg, Rg_pot, Tair, VPD, precip, |
control |
see |
ds with filters and additional indices
cswi: see compute_cswi,
C_ET, C_Rg: diurnal centroids,
see compute_diurnal_centroid,
dcwi: see compute_DWCI,
Rg_pot_daily: daily daily Rg_pot in MJ m-2 d-1
year: the year of the time-stamp
use mid-time-stamps. If using end-timestampes, NewYear is already next
GPPgrad: daily smoothed GPP gradient in umol C m-2 s-1 d-1
, which gives and indication of phenology
Rgpotgrad and Rpotgrad_day: gradients in Rpot
and daily means of Rpot, which give an indication of time
in the year, ie. season
tempFlag: records with minimum temperature
(see tea_config)
GPPFlag: records with minimum GPP and minimum daily GPP
(see tea_config)
seasonFlag: combined tempFlag and GPPFlag
inst_WUE: instant water use efficiency (GPP/ET)
in g C per kg H2O
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.